@@ -111,7 +111,7 @@ class EnviarPedido(Enviar):
         if resposta.status_code == 400:
             reenviar = retorno["error"] == "invalid_access_token"
             return {"content": retorno["message"], "status": 401 if reenviar else 400, "reenviar": reenviar}
-        if resposta.status_code == 201:
+        if resposta.status_code in (201, 200):
             return {"content": {"url": retorno["init_point"]}, "status": 200, "reenviar": False, "identificador": retorno["id"]}
         return {"content": retorno, "status": resposta.status_code, "reenviar": False}
 
