@@ -25,15 +25,24 @@ class TipoToken(object):
 class Credenciador(autenticador.Credenciador):
     def __init__(self, configuracao):
         self.conta_id = configuracao.conta_id
+        self.configuracao = configuracao
         self.access_token = getattr(configuracao, "token", "")
         self.refresh_token = getattr(configuracao, "codigo_autorizacao", "")
         self.token_expiracao = getattr(configuracao, "token_expiracao", datetime.now())
         self.tipo = TipoAutenticacao.query_string
 
+    def _atualiza_credenciais(self):
+        self.access_token = getattr(self.configuracao, "token", "")
+        self.refresh_token = getattr(self.configuracao, "codigo_autorizacao", "")
+        self.token_expiracao = getattr(self.configuracao, "token_expiracao", datetime.now())
+
     def obter_credenciais(self):
+        self._atualiza_credenciais()
         return self.access_token
 
     def esta_valido(self):
+        if not self.access_token:
+            return False
         return datetime.now() > self.token_expiracao
 
 
